@@ -5,7 +5,7 @@ package config
 // Defaults for linux/unix if none are specified.
 const (
 	cniConfigDir             = "/etc/cni/net.d/"
-	cniBinDir                = "/usr/lib/cni/"
+	cniBinDir                = "/opt/cni/bin/"
 	containerExitsDir        = "/run/crio/exits"
 	ContainerAttachSocketDir = "/run/crio"
 
